@@ -1,11 +1,21 @@
+import abc
+import functools
 import json
 import os
 
+from typing import Dict, Iterable, Optional, Type
+
 import confuse
 import boto3
 from botocore.exceptions import ClientError
 from cachetools import Cache
 
+try:
+    from aws_secretsmanager_caching import SecretCache
+except ImportError:
+    SecretCache = None
+
+
 required_credentials = [
     'aws_access_key',
     'aws_secret_key',
@@ -21,7 +31,7 @@ class MissingCredentials(Exception):
     pass
 
 
-class BaseCredentialProvider:
+class BaseCredentialProvider(abc.ABC):
     errors = []
     credentials = None
 
@@ -32,8 +42,9 @@ class BaseCredentialProvider:
         self.load_credentials()
         return self.check_credentials()
 
+    @abc.abstractmethod
     def load_credentials(self):
-        raise NotImplementedError()
+        ...
 
     def check_credentials(self):
         try:
@@ -67,28 +78,56 @@ class FromConfigFileCredentialProvider(BaseCredentialProvider):
             return
 
 
-class FromSecretsCredentialProvider(BaseCredentialProvider):
+class BaseFromSecretsCredentialProvider(BaseCredentialProvider):
     def load_credentials(self):
-        if not os.environ.get('SP_API_AWS_SECRET_ID', None):
+        secret_id = os.environ.get('SP_API_AWS_SECRET_ID')
+        if not secret_id:
             return
+        secret = self.get_secret_content(secret_id)
+        if not secret:
+            return
+        self.credentials = dict(
+            refresh_token=secret.get('SP_API_REFRESH_TOKEN'),
+            lwa_app_id=secret.get('LWA_APP_ID'),
+            lwa_client_secret=secret.get('LWA_CLIENT_SECRET'),
+            aws_secret_key=secret.get('SP_API_SECRET_KEY'),
+            aws_access_key=secret.get('SP_API_ACCESS_KEY'),
+            role_arn=secret.get('SP_API_ROLE_ARN')
+        )
+
+    @abc.abstractmethod
+    def get_secret_content(self, secret_id: str) -> Dict[str, str]:
+        ...
+
+
+class FromSecretsCredentialProvider(BaseFromSecretsCredentialProvider):
+    def get_secret_content(self, secret_id: str) -> Dict[str, str]:
         try:
             client = boto3.client('secretsmanager')
-            response = client.get_secret_value(
-                SecretId=os.environ.get('SP_API_AWS_SECRET_ID')
-            )
-            secret = json.loads(response.get('SecretString'))
-            account_data = dict(
-                refresh_token=secret.get('SP_API_REFRESH_TOKEN'),
-                lwa_app_id=secret.get('LWA_APP_ID'),
-                lwa_client_secret=secret.get('LWA_CLIENT_SECRET'),
-                aws_secret_key=secret.get('SP_API_SECRET_KEY'),
-                aws_access_key=secret.get('SP_API_ACCESS_KEY'),
-                role_arn=secret.get('SP_API_ROLE_ARN')
-            )
+            response = client.get_secret_value(SecretId=secret_id)
+            return json.loads(response.get('SecretString'))
         except ClientError:
-            return
-        else:
-            self.credentials = account_data
+            return {}
+
+
+class FromCachedSecretsCredentialProvider(BaseFromSecretsCredentialProvider):
+    def get_secret_content(self, secret_id: str) -> Dict[str, str]:
+        # If caching library is not available, return.
+        secret_cache = self._get_secret_cache()
+        if not secret_cache:
+            return {}
+        try:
+            response = secret_cache.get_secret_string(secret_id=secret_id)
+            return json.loads(response)
+        except ClientError:
+            return {}
+
+    @classmethod
+    @functools.lru_cache(maxsize=None)
+    def _get_secret_cache(cls):
+        if SecretCache is None:
+            return None
+        return SecretCache()
 
 
 class FromEnvironmentVariablesCredentialProvider(BaseCredentialProvider):
@@ -112,16 +151,23 @@ class CredentialProvider:
     credentials = None
     cache = Cache(maxsize=10)
 
-    CREDENTIAL_PROVIDERS = [
+    CREDENTIAL_PROVIDERS: Iterable[Type[BaseCredentialProvider]] = (
         FromCodeCredentialProvider,
         FromEnvironmentVariablesCredentialProvider,
+        FromCachedSecretsCredentialProvider,
         FromSecretsCredentialProvider,
         FromConfigFileCredentialProvider
-    ]
+    )
 
-    def __init__(self, account='default', credentials=None):
+    def __init__(
+        self,
+        account: str = 'default',
+        credentials: Optional[Dict[str, str]] = None,
+        credential_providers: Optional[Iterable[Type[BaseCredentialProvider]]] = None,
+    ):
         self.account = account
-        for cp in self.CREDENTIAL_PROVIDERS:
+        providers = self.CREDENTIAL_PROVIDERS if credential_providers is None else credential_providers
+        for cp in providers:
             try:
                 self.credentials = cp(account=account, credentials=credentials)()
                 break
