@@ -1,11 +1,13 @@
 from .retry import retry, sp_retry, throttle_retry
 from .load_all_pages import load_all_pages
 from .key_maker import KeyMaker
+from .load_date_bound import load_date_bound
 
 __all__ = [
     'retry',
     'sp_retry',
     'throttle_retry',
     'load_all_pages',
-    'KeyMaker'
+    'KeyMaker',
+    'load_date_bound'
 ]
